@@ -3,12 +3,11 @@
 #' User-friendly graphical user interface for relMix.
 #' @return No return value, called for side effects.
 #' @details Includes error checking for the input files.
-#' @author Guro Dorum, Elias Hernandis
+#' @author Guro Dorum, Elias Hernandis, Magnus Dehli Vigeland
 #' @seealso \code{\link{relMix}} for the main function implemented in \code{relMixGUI}.
 #' @examples
 #' #Examples can be found in the vignette and example data files can be found
 #' #in the folder "extdata" in the installation folder for relMix
-#' @import gWidgets2tcltk
 #' @import Familias
 #' @importFrom graphics plot
 #' @importFrom utils read.table write.table packageVersion
@@ -19,6 +18,11 @@
 #' @export
 relMixGUI <- function(){
 
+  if (!requireNamespace("gWidgets2", quietly = TRUE)) {
+    stop("The gWidgets2 package is required for the GUI. Please install it using install.packages('gWidgets2').")}
+  if (!requireNamespace("gWidgets2tcltk", quietly = TRUE)) {
+    stop("The gWidgets2tcltk package is required for the GUI. Please install it using install.packages('gWidgets2tcltk').")}
+
   options("guiToolkit"="tcltk")
 
   tableWriter <- function(filename,obj1,obj2,obj3,obj4,obj5,pedigrees,contributors,mixfile,reffile,freqfile){
